/**
 * 计算签名用的加密密钥ID，[查看秘钥](https://console.cloud.tencent.com/cam/capi)
 * 注意：该方案仅适用于调试Demo，正式上线前请将 UserSig 计算代码和密钥迁移到您的后台服务器上，以避免加密密钥泄露导致的流量盗用。
 *
 * 文档：https://cloud.tencent.com/document/product/679/49227
 */
const Test_SecretId = "";
const Test_SecretKey = "";

/**
 * 您的腾讯云呼叫中心应用ID，需要替换为您自己账号下的 SDKAppId。
 * 
 * 进入腾讯云呼叫中心[控制台](https://console.cloud.tencent.com/ccc ) 创建应用，即可看到 SDKAppId，
 * 它是腾讯云用于区分客户的唯一标识。
 */
export const Test_SdkAppId = 0;
// 您需要登录的坐席邮箱
export const Test_SeatUserId = "";
// 您需要拨打的电话号码
export const Test_CalleePhone = "";

/**
  * 获取坐席登录Token
  *
  * @note: 请不要将如下代码发布到您的线上正式版本的 App 中，原因如下：
  *
  * 本文件中的代码虽然能够正确计算出 UserSig，但仅适合快速调通 SDK 的基本功能，不适合线上产品，
  * 这是因为客户端代码中的 SECRETKEY 很容易被反编译逆向破解，尤其是 Web 端的代码被破解的难度几乎为零。
  * 一旦您的密钥泄露，攻击者就可以计算出正确的 UserSig 来盗用您的腾讯云流量。
  *
  * 正确的做法是将 UserSig 的计算代码和加密密钥放在您的业务服务器上，然后由 App 按需向您的服务器获取实时算出的 UserSig。
  * 由于破解服务器的成本要高于破解客户端 App，所以服务器计算的方案能够更好地保护您的加密密钥。
  *
  * 文档：https://cloud.tencent.com/document/product/679/49227
  * @returns Token
  */
export function getSeatUserDebugLoginToken(){
  return new Promise((resolve, reject) => {
    wx.request({
      url: 'https://tccc-gavin-5g19jovqc598f12b-1258344699.ap-guangzhou.app.tcloudbase.com/tccc-agent',
      data: {
        secretId: Test_SecretId,
        secretKey: Test_SecretKey,
        SdkAppId: Test_SdkAppId,
        SeatUserId: Test_SeatUserId
      },
      success:(res)=>{
        const data:any = res.data;
        if(data.errorCode == 0) {
          resolve(data.Token);
        }else {
          reject(data);
        }
      },
      fail: (error)=>{
        reject(error);
      }
    });
  });
}