// index.ts

import { getSeatUserDebugLoginToken,Test_SdkAppId,Test_SeatUserId, Test_CalleePhone } from "./debugInfo";

// 获取应用实例

Page({
  data: {
    logList:['tccc init'],
    calleePhone: Test_CalleePhone,
    _DTMFValue: '816869',
  },
  bindKeyPhoneInput(e: { detail: { value: any; }; }) {
    this.setData({
      calleePhone: e.detail.value
    })
  },
  bindKeyDTMFInput(e: { detail: { value: any; }; }){
    this.setData({
      calleePhone: e.detail.value
    })
  },
  async bindBtnLoginTap() {
    this._addActiveFuncLog('bindBtnLoginTap login');
    const token = await getSeatUserDebugLoginToken();
    try {
      await this.selectComponent('#sdk').login({
        sdkAppId: Test_SdkAppId,
        userId: Test_SeatUserId,
        token: token,
      });
      const line = 'login success';
      wx.showToast({
        title: line,
        icon: 'success',
        duration: 2000
      });
      this._addFunResultLog(line);
    } catch (error:any) {
      const line = `login errorCode:${error.errorCode},msg:${error.msg}`;
      this._addFunResultLog(line);
      wx.showToast({
        title: line,
        duration: 2000
      }); 
    }
  },
  async bindBtnLogoutTap(){
    this._addActiveFuncLog('bindBtnLogoutTap logout');
    await this.selectComponent('#sdk').logout();
  },
  async bindBtnIsLoginTap(){
    this._addActiveFuncLog('bindBtnIsLoginTap isLogin');
    const isOk = await this.selectComponent('#sdk').isLogin();
    this._addFunResultLog(`isLogin ${isOk}`);
  },
  async bindBtnCallTap(){
    this._addActiveFuncLog('bindBtnCallTap');
    try {
      await this.selectComponent('#sdk').call({
        calleePhone: this.data.calleePhone,
      });
      this._addFunResultLog(`start call success`);
    } catch (error:any) {
      this._addFunResultLog(`start call error:${error.msg}`);
      wx.showToast({
        title: `start call error:${error.msg}`,
        duration: 2000
      });   
    }  
  },
  async bindBtnSendDTMFTap(){
    this._addActiveFuncLog('bindBtnSendDMFTap');
    await this.selectComponent('#sdk').sendDigits(this.data._DTMFValue);
    this._addFunResultLog(`sendDigits success`);
  },
  async bindBtnEndCallTap() {
    this._addActiveFuncLog('bindBtnEndCallTap');
    await this.selectComponent('#sdk').terminate();
    this._addFunResultLog(`terminate success`);
  },
  bindBtnMuteTap() {
    this._addActiveFuncLog('bindBtnMuteTap');
    this.selectComponent('#sdk').muteMic();
  },
  bindBtnUnMuteTap() {
    this._addActiveFuncLog('bindBtnUnMuteTap');
    this.selectComponent('#sdk').unMuteMic();
  },
  bindBtnEnableEarTap() {
    this._addActiveFuncLog('bindBtnEnableEarTap ear');
    this.selectComponent('#sdk').setSoundMode('ear');
  },
  bindBtnEnableSpeakerTap() {
    this._addActiveFuncLog('bindBtnEnableSpeakerTap speaker');
    this.selectComponent('#sdk').setSoundMode('speaker');
  },
  async bindBtnHoldTap() {
    this._addActiveFuncLog('bindBtnHoldTap');
    await this.selectComponent('#sdk').hold();
    this._addFunResultLog(`hold success`);
  },
  async bindBtnUnHoldTap() {
    this._addActiveFuncLog('bindBtnUnHoldTap');
    await this.selectComponent('#sdk').unHold();
    this._addFunResultLog(`unHold success`);
  },
  bindBtnClearLogTap(){
    this.setData({
      logList: ["==> bindBtnClearLogTap"]
    });
  },
  onProgress() {
    this._addCallBackLog('onProgress');
  },
  onAccepted() {
    this._addCallBackLog('onAccepted');
  },
  onEnded(e:{ detail: { closeBy: string;mainReason?: string }; }) {
   const {closeBy,mainReason} = e.detail;
   this._addCallBackLog(`onEnded ${closeBy}, mainReason:${mainReason}`);
   if (closeBy === 'admin') {
      wx.showToast({
        icon: 'none', // 自选合适的图标
        title: '系统原因挂断'
      })
    } else if(closeBy === 'seat') {
      wx.showToast({
        icon: 'none', // 自选合适的图标
        title: '通话结束，对方已挂断'
      })   
    } else {
      // 挂断成功   
    }
  },
  onLoad() {
  },
  _addActiveFuncLog(line:string) {
    this.setData({
      logList: [...this.data.logList,"==> "+line]
    });
  },
  _addFunResultLog(line:string){
    this.setData({
      logList: [...this.data.logList," "+line]
    });
  },
  _addCallBackLog(line:string) {
    this.setData({
      logList: [...this.data.logList,"<== "+line]
    });
  }
})
